package com.csc.library.factory;

import java.util.Collections;
import java.util.HashMap;
import java.util.Map;

import com.csc.library.modecontroller.AbsModeManagement;
import com.csc.library.modecontroller.CMDModeManagement;
import com.csc.library.modecontroller.ManageCommonMode;
import com.csc.library.modecontroller.ManageProcessMode;
import com.csc.library.modecontroller.ManageSpecialMode;
import com.csc.library.modecontroller.ManageFtpMode;
import com.csc.library.request.CMDMode;
import com.csc.library.session.InitialEnvironment;

public class CMDModeFactory {
	private static CMDModeFactory instance;
	private Map<CMDMode , AbsModeManagement> mapMode = new HashMap<CMDMode,AbsModeManagement>();
	private String path = new InitialEnvironment().getValue("COMMAND_CONFIG-dir");
	private CMDModeFactory(){
		init();
	}
	
	protected synchronized void init(){
		if(instance == null){
			mapMode.put(CMDMode.common, new ManageCommonMode());
			mapMode.put(CMDMode.special, new ManageSpecialMode());
			mapMode.put(CMDMode.process, new ManageProcessMode());
			mapMode.put(CMDMode.ftp, new ManageFtpMode());
			
			if(CMDMode.values().length == mapMode.size()){
				mapMode = Collections.unmodifiableMap(mapMode);
				
				for(AbsModeManagement manager : mapMode.values()){
					manager.load(path);
				}
			}
		}
	}
	
	public static CMDModeFactory getInstance(){
		if(instance == null){
			instance = new CMDModeFactory();
		}
		return instance;
	}
	
	public CMDModeManagement.ModeCtrl getModeCtrl(CMDMode mode){
		return this.mapMode.get(mode);
	}
	
	public CMDModeManagement.ModeBuilder getModeBuilder(CMDMode mode){
		return this.mapMode.get(mode);
	}
	
	public void load(){
		for(AbsModeManagement manager : mapMode.values()){
			manager.load(path);
		}
	}
	
	public void load(CMDMode mode){
		if(mapMode.containsKey(mode)){
			mapMode.get(mode).load(path);
		}
	}
}
